@@ -108,7 +108,6 @@ enum string_id {
     MEMINIT_S,
     METASYNC_S,
     MODE_S,
-    NAME_S,
     OVERWRITE_S,
     PARENT_S,
     PATH_S,
@@ -159,7 +158,6 @@ static const char *strings = (
     "meminit\0"
     "metasync\0"
     "mode\0"
-    "name\0"
     "overwrite\0"
     "parent\0"
     "path\0"
@@ -477,6 +475,67 @@ static const struct error_map error_map[] = {
     {ENOSPC, "DiskError"}
 };
 
+
+/* ---------- */
+/* Exceptions */
+/* ---------- */
+
+/**
+ * Raise an exception appropriate for the given `rc` MDB error code.
+ */
+static void * NOINLINE
+err_set(const char *what, int rc)
+{
+    size_t count = sizeof error_map / sizeof error_map[0];
+    PyObject *klass = Error;
+    size_t i;
+
+    if(rc) {
+        for(i = 0; i < count; i++) {
+            if(error_map[i].code == rc) {
+                klass = error_tbl[i];
+                break;
+            }
+        }
+    }
+
+    PyErr_Format(klass, "%s: %s", what, mdb_strerror(rc));
+    return NULL;
+}
+
+static void * NOINLINE
+err_invalid(void)
+{
+    PyErr_Format(Error, "Attempt to operate on closed/deleted/dropped object.");
+    return NULL;
+}
+
+static void * NOINLINE
+type_error(const char *what)
+{
+    PyErr_Format(PyExc_TypeError, "%s", what);
+    return NULL;
+}
+
+/**
+ * Convert a PyObject to filesystem bytes. Must call fspath_fini() when done.
+ * Return 0 on success, or set an exception and return -1 on failure.
+ */
+static PyObject *
+get_fspath(PyObject *src)
+{
+    if(PyBytes_CheckExact(src)) {
+        Py_INCREF(src);
+        return src;
+    }
+    if(! PyUnicode_CheckExact(src)) {
+        type_error("Filesystem path must be Unicode or bytes.");
+        return NULL;
+    }
+    return PyUnicode_AsEncodedString(src, Py_FileSystemDefaultEncoding,
+                                     "strict");
+}
+
 /* ------- */
 /* Helpers */
 /* ------- */
@@ -588,18 +647,10 @@ val_from_buffer(MDB_val *val, PyObject *buf)
         val->mv_size = PyBytes_GET_SIZE(buf);
         return 0;
     }
-#if PY_MAJOR_VERSION >= 3
     if(PyUnicode_CheckExact(buf)) {
-        char *data;
-        Py_ssize_t size;
-        if(! (data = PyUnicode_AsUTF8AndSize(buf, &size))) {
-            return -1;
-        }
-        val->mv_data = data;
-        val->mv_size = size;
-        return 0;
+        type_error("Won't implicitly convert Unicode to bytes; use .encode()");
+        return -1;
     }
-#endif
     return PyObject_AsReadBuffer(buf,
         (const void **) &val->mv_data,
         (Py_ssize_t *) &val->mv_size);
@@ -616,67 +667,6 @@ val_from_buffer(MDB_val *val, PyObject *buf)
     Py_END_ALLOW_THREADS
 
 
-/* ---------- */
-/* Exceptions */
-/* ---------- */
-
-/**
- * Raise an exception appropriate for the given `rc` MDB error code.
- */
-static void * NOINLINE
-err_set(const char *what, int rc)
-{
-    size_t count = sizeof error_map / sizeof error_map[0];
-    PyObject *klass = Error;
-    size_t i;
-
-    if(rc) {
-        for(i = 0; i < count; i++) {
-            if(error_map[i].code == rc) {
-                klass = error_tbl[i];
-                break;
-            }
-        }
-    }
-
-    PyErr_Format(klass, "%s: %s", what, mdb_strerror(rc));
-    return NULL;
-}
-
-static void * NOINLINE
-err_invalid(void)
-{
-    PyErr_Format(Error, "Attempt to operate on closed/deleted/dropped object.");
-    return NULL;
-}
-
-static void * NOINLINE
-type_error(const char *what)
-{
-    PyErr_Format(PyExc_TypeError, "%s", what);
-    return NULL;
-}
-
-/**
- * Convert a PyObject to filesystem bytes. Must call fspath_fini() when done.
- * Return 0 on success, or set an exception and return -1 on failure.
- */
-static PyObject *
-get_fspath(PyObject *src)
-{
-    if(PyBytes_CheckExact(src)) {
-        Py_INCREF(src);
-        return src;
-    }
-    if(! PyUnicode_CheckExact(src)) {
-        type_error("Filesystem path must be Unicode or bytes.");
-        return NULL;
-    }
-    return PyUnicode_AsEncodedString(src, Py_FileSystemDefaultEncoding,
-                                     "strict");
-}
-
-
 /* ---------------- */
 /* Argument parsing */
 /* ---------------- */
@@ -1552,7 +1542,7 @@ static PyObject *
 env_open_db(EnvObject *self, PyObject *args, PyObject *kwds)
 {
     struct env_open_db {
-        const char *name;
+        const char *key;
         TransObject *txn;
         int reverse_key;
         int dupsort;
@@ -1560,7 +1550,7 @@ env_open_db(EnvObject *self, PyObject *args, PyObject *kwds)
     } arg = {NULL, NULL, 0, 0, 1};
 
     static const struct argspec argspec[] = {
-        {ARG_STR, NAME_S, OFFSET(env_open_db, name)},
+        {ARG_STR, KEY_S, OFFSET(env_open_db, key)},
         {ARG_TRANS, TXN_S, OFFSET(env_open_db, txn)},
         {ARG_BOOL, REVERSE_KEY_S, OFFSET(env_open_db, reverse_key)},
         {ARG_BOOL, DUPSORT_S, OFFSET(env_open_db, dupsort)},
@@ -1584,9 +1574,9 @@ env_open_db(EnvObject *self, PyObject *args, PyObject *kwds)
     }
 
     if(arg.txn) {
-        return (PyObject *) db_from_name(self, arg.txn->txn, arg.name, flags);
+        return (PyObject *) db_from_name(self, arg.txn->txn, arg.key, flags);
     } else {
-        return (PyObject *) txn_db_from_name(self, arg.name, flags);
+        return (PyObject *) txn_db_from_name(self, arg.key, flags);
     }
 }
 
